@@ -1,8 +1,10 @@
 __all__ = [
+    'OnEvent',
     'CommandSender',
     'Result',
     'RunSession',
     'Signal',
 ]
 
+from .monitor import OnEvent
 from .session import CommandSender, Result, RunSession, Signal
