@@ -1,6 +1,5 @@
 '''Code used in the sub-processes in which the Nextline user code is run.
 '''
-from __future__ import annotations
 
 __all__ = [
     'Command',
@@ -26,24 +25,14 @@ __all__ = [
 
 import traceback
 
+from nextline.utils import wait_until_queue_empty
+
 from .commands import Command, PdbCommand
-from .events import (
-    Event,
-    OnEndCmdloop,
-    OnEndPrompt,
-    OnEndTrace,
-    OnEndTraceCall,
-    OnStartCmdloop,
-    OnStartPrompt,
-    OnStartTrace,
-    OnStartTraceCall,
-    OnWriteStdout,
-)
 from .runner import run
 from .types import QueueIn, QueueOut, RunArg, RunResult, Statement
 
-_queue_in: QueueIn | None = None
-_queue_out: QueueOut | None = None
+_queue_in: 'QueueIn | None' = None
+_queue_out: 'QueueOut | None' = None
 
 
 def set_queues(queue_in: QueueIn, queue_out: QueueOut) -> None:
@@ -58,7 +47,9 @@ def main(run_arg: RunArg) -> RunResult:
     assert _queue_in
     assert _queue_out
     try:
-        return run(run_arg, _queue_in, _queue_out)
+        ret = run(run_arg, _queue_in, _queue_out)
+        wait_until_queue_empty(queue=_queue_out)
+        return ret
     except BaseException:
         traceback.print_exc()
         raise
