@@ -1,11 +1,12 @@
 __all__ = ['register']
 
-
 from apluggy import PluginManager
 
+from nextline.spawned.types import RunArg
+
 from .compose import CallableComposer
 from .concurrency import TaskAndThreadKeeper, TaskOrThreadToTraceMapper
-from .filter import FilerByModule, FilterByModuleName, FilterLambda
+from .filter import FilerByModule, FilterByModuleName, FilterLambda, FilterMainScript
 from .global_ import GlobalTraceFunc, TraceFuncCreator
 from .local_ import LocalTraceFunc, TraceCallHandler
 from .pdb_ import PdbInstanceFactory, Prompt
@@ -13,7 +14,7 @@ from .peek import PeekStdout
 from .repeat import Repeater
 
 
-def register(hook: PluginManager) -> None:
+def register(hook: PluginManager, run_arg: RunArg) -> None:
     hook.register(Repeater)
     hook.register(PeekStdout)
     hook.register(Prompt)
@@ -22,9 +23,13 @@ def register(hook: PluginManager) -> None:
     hook.register(LocalTraceFunc)
     hook.register(TaskOrThreadToTraceMapper)
     hook.register(TaskAndThreadKeeper)
-    hook.register(FilerByModule)
-    hook.register(FilterLambda)
-    hook.register(FilterByModuleName)
+    if run_arg.trace_modules:
+        hook.register(FilerByModule)
+        hook.register(FilterLambda)
+        hook.register(FilterByModuleName)
+    else:
+        hook.register(FilterLambda)
+        hook.register(FilterMainScript)
     hook.register(GlobalTraceFunc)
     hook.register(TraceFuncCreator)
     hook.register(CallableComposer)
