@@ -1,5 +1,6 @@
 from logging import getLogger
-from typing import Optional
+from types import FrameType
+from typing import Any, Optional
 
 from apluggy import PluginManager
 
@@ -15,7 +16,9 @@ class TraceFuncCreator:
 
     @hookimpl
     def create_trace_func(self) -> TraceFunction:
-        def _trace_func(frame, event, arg) -> Optional[TraceFunction]:
+        def _trace_func(
+            frame: FrameType, event: str, arg: Any
+        ) -> Optional[TraceFunction]:
             try:
                 return self._hook.hook.global_trace_func(
                     frame=frame, event=event, arg=arg
@@ -33,7 +36,9 @@ class GlobalTraceFunc:
         self._hook = hook
 
     @hookimpl
-    def global_trace_func(self, frame, event, arg) -> Optional[TraceFunction]:
+    def global_trace_func(
+        self, frame: FrameType, event: str, arg: Any
+    ) -> Optional[TraceFunction]:
         if self._hook.hook.filter(trace_args=(frame, event, arg)):
             return None
         self._hook.hook.filtered(trace_args=(frame, event, arg))
