@@ -1,10 +1,6 @@
-from __future__ import annotations
-
 import time
-from asyncio import Task, current_task
-from typing import Any, Callable, List, Optional, Set
-
-from nextline.utils.func import to_thread
+from asyncio import Task, current_task, to_thread
+from typing import Any, Callable, Optional
 
 
 class TaskDoneCallback:
@@ -23,8 +19,8 @@ class TaskDoneCallback:
 
     def __init__(self, done: Optional[Callable[[Task], Any]] = None):
         self._done = done
-        self._active: Set[Task] = set()
-        self._exceptions: List[BaseException] = []
+        self._active = set[Task]()
+        self._exceptions = list[BaseException]()
 
     def register(self, task: Optional[Task] = None) -> Task:
         """Add the current task by default, or the given task
@@ -84,7 +80,7 @@ class TaskDoneCallback:
         while self._active:
             time.sleep(interval)
 
-    def _callback(self, task: Task, *_, **__):
+    def _callback(self, task: Task, *_: Any, **__: Any) -> None:
         """This method is given to asyncio.Task.add_done_callback()
 
         When called, this method, in turn, calls the callback function
@@ -105,16 +101,16 @@ class TaskDoneCallback:
         except BaseException as e:
             self._exceptions.append(e)
 
-    def __enter__(self):
+    def __enter__(self) -> "TaskDoneCallback":
         return self
 
-    def __exit__(self, exc_type, exc_value, traceback):
+    def __exit__(self, exc_type, exc_value, traceback):  # type: ignore
         del exc_type, exc_value, traceback
         self.close()
 
-    async def __aenter__(self):
+    async def __aenter__(self) -> "TaskDoneCallback":
         return self
 
-    async def __aexit__(self, exc_type, exc_value, traceback):
+    async def __aexit__(self, exc_type, exc_value, traceback):  # type: ignore
         del exc_type, exc_value, traceback
         await self.aclose()
