@@ -1,14 +1,12 @@
-from __future__ import annotations
-
 import cProfile
 import pstats
 from io import StringIO
-from typing import Callable, Tuple, TypeVar
+from typing import Callable, TypeVar
 
 _T = TypeVar("_T")
 
 
-def profile_func(func: Callable[[], _T]) -> Tuple[str, _T]:
+def profile_func(func: Callable[[], _T]) -> tuple[str, _T]:
     with cProfile.Profile() as pr:
         ret = func()
     sortby = "cumulative"
